@@ -9,9 +9,9 @@
 #ifndef LLDB_HOST_CONFIG_H
 #define LLDB_HOST_CONFIG_H
 
-#define LLDB_EDITLINE_USE_WCHAR 0
+#define LLDB_EDITLINE_USE_WCHAR 1
 
-#define LLDB_HAVE_EL_RFUNC_T 0
+#define LLDB_HAVE_EL_RFUNC_T 1
 
 #define HAVE_SYS_EVENT_H 0
 
@@ -37,7 +37,7 @@
 
 #define CURSES_HAVE_NCURSES_CURSES_H 0
 
-#define LLDB_ENABLE_LIBEDIT 0
+#define LLDB_ENABLE_LIBEDIT 1
 
 #define LLDB_ENABLE_LIBXML2 1
 
@@ -51,7 +51,7 @@
 
 /* #undef LLDB_PYTHON_HOME */
 
-#define LLDB_LIBDIR_SUFFIX ""
+#define LLDB_INSTALL_LIBDIR_BASENAME "lib"
 
 /* #undef LLDB_GLOBAL_INIT_DIRECTORY */
 
